@@ -1,28 +1,28 @@
 package proxy
 
 import (
-	"inet.af/netaddr"
+	"net/netip"
 	"sync"
 )
 
 type RealIPMapper struct {
-	mapper map[netaddr.IP]netaddr.IP
+	mapper map[netip.Addr]netip.Addr
 	mutex  sync.Mutex
 }
 
 func NewRealIPMapper() *RealIPMapper {
 	return &RealIPMapper{
-		mapper: make(map[netaddr.IP]netaddr.IP),
+		mapper: make(map[netip.Addr]netip.Addr),
 	}
 }
 
-func (m *RealIPMapper) Set(fakeIP netaddr.IP, realIP netaddr.IP) {
+func (m *RealIPMapper) Set(fakeIP netip.Addr, realIP netip.Addr) {
 	m.mutex.Lock()
 	defer m.mutex.Unlock()
 	m.mapper[fakeIP] = realIP
 }
 
-func (m *RealIPMapper) Get(fakeIP netaddr.IP) (realIP netaddr.IP, ok bool) {
+func (m *RealIPMapper) Get(fakeIP netip.Addr) (realIP netip.Addr, ok bool) {
 	m.mutex.Lock()
 	defer m.mutex.Unlock()
 	realIP, ok = m.mapper[fakeIP]
